package com.jiayue.ssi.controller;

import cn.hutool.core.lang.Validator;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jiayue.ssi.annotation.InterfaceLimit;

import com.jiayue.ssi.annotation.OperateLog;
import com.jiayue.ssi.backenum.BusinessType;
import com.jiayue.ssi.entity.SysParameter;
import com.jiayue.ssi.entity.SysRole;

import com.jiayue.ssi.entity.SysUser;
import com.jiayue.ssi.service.SysRoleService;
import com.jiayue.ssi.util.ResponseVO;
import com.jiayue.ssi.util.SecurityContextUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;


/**
 * 角色接口
 *
 * @author xsl
 * @since 2023/03/21
 */
@RestController
@RequestMapping("/sysRoleController")
@Slf4j
public class SysRoleController {
    @Autowired
    SysRoleService roleService;
//
//    @Autowired
//    private TokenService tokenService;
//
//    @Autowired
//    private SysPermissionService permissionService;
//
//    @Autowired
//    private ISysUserService userService;
//
//    @Autowired
//    private ISysDeptService deptService;


    /**
     * 获取参数分页信息
     *
     * @return 参数信息
     */
    //    @PreAuthorize("@ss.hasPermi('system:role:list')")
    @GetMapping(value = "/getAll")
    @InterfaceLimit
    public ResponseVO getAll(Integer currentPage, Integer pageSize, String roleName, String status, String roleKey) {
        try {
            QueryWrapper<SysRole> wrapper = new QueryWrapper<>();
            if (StringUtils.isNotEmpty(roleName)) {
                wrapper.like("role_name", roleName);
            }
            if (StringUtils.isNotEmpty(status)) {
                wrapper.eq("status", status);
            }
            if (StringUtils.isNotEmpty(roleKey)) {
                wrapper.like("role_key", roleKey);
            }
            Page<SysRole> result = roleService.page(new Page<>(currentPage, pageSize), wrapper);
            return ResponseVO.success(result);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("获取参数异常");
            return ResponseVO.error(null);
        }
    }

    /**
     * 新增角色
     *
     * @param role 角色
     * @return 执行结果
     */
    @InterfaceLimit
    @PostMapping()
    @OperateLog(title = "角色管理", businessType = BusinessType.INSERT)
    public ResponseVO add(@RequestBody SysRole role) {
        try {
            ///////加校验/////
            role.setCreateBy(SecurityContextUtil.getSysUser().getUsername());
            int i = roleService.insertRole(role);
            if (i > 0) {
                return ResponseVO.success("添加角色成功");
            } else {
                log.error("添加角色失败");
                return ResponseVO.fail("添加角色失败");
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("添加角色异常");
            return ResponseVO.error(e);
        }
    }

    /**
     * 更新角色
     *
     * @param role 参数
     * @return 执行结果
     */
    @InterfaceLimit
    @PutMapping
    @OperateLog(title = "角色管理", businessType = BusinessType.UPDATE)
    public ResponseVO update(@RequestBody SysRole role) {
        SysRole existRole = roleService.getById(role.getRoleId());
        if (existRole == null) {
            return ResponseVO.fail("非法访问不能修改!");
        }
///////加校验/////
        try {
            if (roleService.updateRole(role) > 0) {
                return ResponseVO.success("修改角色信息成功");
            } else {
                log.error("修改用户信息失败");
                return ResponseVO.fail("修改角色信息失败");
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("修改角色信息异常");
            return ResponseVO.error(e);
        }
    }

    /**
     * 根据角色编号获取详细信息
     */
    @GetMapping(value = "getInfo")
    public ResponseVO getInfo(Long roleId) {
        return ResponseVO.success(roleService.selectRoleById(roleId));
    }

    /**
     * 删除角色
     */
    @PostMapping(value = "/delRole")
    @InterfaceLimit
    @OperateLog(title = "角色管理", businessType = BusinessType.DELETE)
    public ResponseVO delRole(String roleId) {
        if (StringUtils.isEmpty(roleId)) {
            return ResponseVO.fail("id不能为空!");
        }
        try {
            int bo = roleService.deleteRoleById(Long.parseLong(roleId));
            if (bo > 0) {
                return ResponseVO.success("删除角色信息成功");
            } else {
                log.error("删除用户信息失败");
                return ResponseVO.fail("删除角色信息失败");
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("删除角色信息异常");
            return ResponseVO.error(e);
        }
    }

//    @Log(title = "角色管理", businessType = BusinessType.EXPORT)
//    @PreAuthorize("@ss.hasPermi('system:role:export')")
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, SysRole role)
//    {
//        List<SysRole> list = roleService.selectRoleList(role);
//        ExcelUtil<SysRole> util = new ExcelUtil<SysRole>(SysRole.class);
//        util.exportExcel(response, list, "角色数据");
//    }
//
//    /**
//     * 根据角色编号获取详细信息
//     */
//    @PreAuthorize("@ss.hasPermi('system:role:query')")
//    @GetMapping(value = "/{roleId}")
//    public AjaxResult getInfo(@PathVariable Long roleId)
//    {
//        roleService.checkRoleDataScope(roleId);
//        return success(roleService.selectRoleById(roleId));
//    }
//
//    /**
//     * 新增角色
//     */
//    @PreAuthorize("@ss.hasPermi('system:role:add')")
//    @Log(title = "角色管理", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@Validated @RequestBody SysRole role)
//    {
//        if (UserConstants.NOT_UNIQUE.equals(roleService.checkRoleNameUnique(role)))
//        {
//            return error("新增角色'" + role.getRoleName() + "'失败，角色名称已存在");
//        }
//        else if (UserConstants.NOT_UNIQUE.equals(roleService.checkRoleKeyUnique(role)))
//        {
//            return error("新增角色'" + role.getRoleName() + "'失败，角色权限已存在");
//        }
//        role.setCreateBy(getUsername());
//        return toAjax(roleService.insertRole(role));
//
//    }
//
//    /**
//     * 修改保存角色
//     */
//    @PreAuthorize("@ss.hasPermi('system:role:edit')")
//    @Log(title = "角色管理", businessType = BusinessType.UPDATE)
//    @PutMapping
//    public AjaxResult edit(@Validated @RequestBody SysRole role)
//    {
//        roleService.checkRoleAllowed(role);
//        roleService.checkRoleDataScope(role.getRoleId());
//        if (UserConstants.NOT_UNIQUE.equals(roleService.checkRoleNameUnique(role)))
//        {
//            return error("修改角色'" + role.getRoleName() + "'失败，角色名称已存在");
//        }
//        else if (UserConstants.NOT_UNIQUE.equals(roleService.checkRoleKeyUnique(role)))
//        {
//            return error("修改角色'" + role.getRoleName() + "'失败，角色权限已存在");
//        }
//        role.setUpdateBy(getUsername());
//
//        if (roleService.updateRole(role) > 0)
//        {
//            // 更新缓存用户权限
//            LoginUser loginUser = getLoginUser();
//            if (StringUtils.isNotNull(loginUser.getUser()) && !loginUser.getUser().isAdmin())
//            {
//                loginUser.setPermissions(permissionService.getMenuPermission(loginUser.getUser()));
//                loginUser.setUser(userService.selectUserByUserName(loginUser.getUser().getUserName()));
//                tokenService.setLoginUser(loginUser);
//            }
//            return success();
//        }
//        return error("修改角色'" + role.getRoleName() + "'失败，请联系管理员");
//    }
//
//    /**
//     * 修改保存数据权限
//     */
//    @PreAuthorize("@ss.hasPermi('system:role:edit')")
//    @Log(title = "角色管理", businessType = BusinessType.UPDATE)
//    @PutMapping("/dataScope")
//    public AjaxResult dataScope(@RequestBody SysRole role)
//    {
//        roleService.checkRoleAllowed(role);
//        roleService.checkRoleDataScope(role.getRoleId());
//        return toAjax(roleService.authDataScope(role));
//    }
//
//    /**
//     * 状态修改
//     */
//    @PreAuthorize("@ss.hasPermi('system:role:edit')")
//    @Log(title = "角色管理", businessType = BusinessType.UPDATE)
//    @PutMapping("/changeStatus")
//    public AjaxResult changeStatus(@RequestBody SysRole role)
//    {
//        roleService.checkRoleAllowed(role);
//        roleService.checkRoleDataScope(role.getRoleId());
//        role.setUpdateBy(getUsername());
//        return toAjax(roleService.updateRoleStatus(role));
//    }
//
//    /**
//     * 删除角色
//     */
//    @PreAuthorize("@ss.hasPermi('system:role:remove')")
//    @Log(title = "角色管理", businessType = BusinessType.DELETE)
//    @DeleteMapping("/{roleIds}")
//    public AjaxResult remove(@PathVariable Long[] roleIds)
//    {
//        return toAjax(roleService.deleteRoleByIds(roleIds));
//    }
//
//    /**
//     * 获取角色选择框列表
//     */
//    @PreAuthorize("@ss.hasPermi('system:role:query')")
//    @GetMapping("/optionselect")
//    public AjaxResult optionselect()
//    {
//        return success(roleService.selectRoleAll());
//    }
//
//    /**
//     * 查询已分配用户角色列表
//     */
//    @PreAuthorize("@ss.hasPermi('system:role:list')")
//    @GetMapping("/authUser/allocatedList")
//    public TableDataInfo allocatedList(SysUser user)
//    {
//        startPage();
//        List<SysUser> list = userService.selectAllocatedList(user);
//        return getDataTable(list);
//    }
//
//    /**
//     * 查询未分配用户角色列表
//     */
//    @PreAuthorize("@ss.hasPermi('system:role:list')")
//    @GetMapping("/authUser/unallocatedList")
//    public TableDataInfo unallocatedList(SysUser user)
//    {
//        startPage();
//        List<SysUser> list = userService.selectUnallocatedList(user);
//        return getDataTable(list);
//    }
//
//    /**
//     * 取消授权用户
//     */
//    @PreAuthorize("@ss.hasPermi('system:role:edit')")
//    @Log(title = "角色管理", businessType = BusinessType.GRANT)
//    @PutMapping("/authUser/cancel")
//    public AjaxResult cancelAuthUser(@RequestBody SysUserRole userRole)
//    {
//        return toAjax(roleService.deleteAuthUser(userRole));
//    }
//
//    /**
//     * 批量取消授权用户
//     */
//    @PreAuthorize("@ss.hasPermi('system:role:edit')")
//    @Log(title = "角色管理", businessType = BusinessType.GRANT)
//    @PutMapping("/authUser/cancelAll")
//    public AjaxResult cancelAuthUserAll(Long roleId, Long[] userIds)
//    {
//        return toAjax(roleService.deleteAuthUsers(roleId, userIds));
//    }
//
//    /**
//     * 批量选择用户授权
//     */
//    @PreAuthorize("@ss.hasPermi('system:role:edit')")
//    @Log(title = "角色管理", businessType = BusinessType.GRANT)
//    @PutMapping("/authUser/selectAll")
//    public AjaxResult selectAuthUserAll(Long roleId, Long[] userIds)
//    {
//        roleService.checkRoleDataScope(roleId);
//        return toAjax(roleService.insertAuthUsers(roleId, userIds));
//    }
//
//    /**
//     * 获取对应角色部门树列表
//     */
//    @PreAuthorize("@ss.hasPermi('system:role:query')")
//    @GetMapping(value = "/deptTree/{roleId}")
//    public AjaxResult deptTree(@PathVariable("roleId") Long roleId)
//    {
//        AjaxResult ajax = AjaxResult.success();
//        ajax.put("checkedKeys", deptService.selectDeptListByRoleId(roleId));
//        ajax.put("depts", deptService.selectDeptTreeList(new SysDept()));
//        return ajax;
//    }
}
